@@ -1,7 +1,7 @@
-".First.lib" <-function (lib, pack)
+".First.lib" <-function (lib, pkg)
 {
 #cat ("Loading package: Lib is ",lib, " and Pack is ",pack,"\n");
 #Loading C library
-  library.dynam ("mcga", pack, lib);
+  library.dynam ("mcga", pkg, lib);
 
 }
